==> ejc-hrm-api-3.0.0-20251204.102149-3-sources.jar: com/ejianc/business/hrm/vo/UserChangeVO.java <==
package com.ejianc.business.hrm.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 异动
 * 
 * @author generator
 * 
 */
public class UserChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private Long createUserId; // 创建人
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String userCode; // 用户编号
    private String userNum; // 用户序号
    private String baseCode; // 库编号
    private String oldOrgName; // 原单位名称
    private String oldDeptName; // 原部门名称
    private String oldPostName; // 原岗位名称
    private String oldOrgCode; // 原单位编号
    private String oldDeptCode; // 原部门编号
    private String oldPostCode; // 原岗位编号
    private String userName; // 姓名
    private String sexName; // 性别
    private String sexCode; // 性别编号
    private String age; // 年龄
    private String degreesName; // 学历
    private String degreesCode; // 学历编号
    private String jobTitleName; // 职称
    private String jobTitleCode; // 职称编号
    private String certificateName; // 执业资格
    private String certificateCode; // 执业资格编号
    private String oldUserTypeName; // 异动前人员类别
    private String oldUserTypeCode; // 异动前人员类别编号
    private String newUserTypeName; // 异动后人员类别
    private String newUserTypeCode; // 异动后人员类别编号
    private String newOrgName; // 调动后单位
    private String newDeptName; // 调动后部门
    private String newPostName; // 调动后岗位
    private String newOrgCode; // 调动后单位编号
    private String newDeptCode; // 调动后部门编号
    private String newPostCode; // 调动后岗位编号
    private String oldPostNumName; // 原所属岗位序列
    private String oldPostNumCode; // 原所属岗位序列
    private String newPostNumName; // 调动后所属岗位序列
    private String newPostNumCode; // 调动后所属岗位序列
    private String oldSocialOrgName; // 原社保参保单位
    private String oldSocialOrgCode; // 原社保参保单位编号
    private String newSocialOrgName; // 调动后参保单位
    private String newSocialOrgCode; // 调动后参保单位编号
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeTime; // 变动时间
    private String changeTypeName; // 异动类型
    private String changeTypeCode; // 异动类型编号
    private String bpmRemark; // 审批意见
    private String changeReason; // 异动原因
    private String billTypeName; // 业务单据名称
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date submitTime; // 业务提交时间
    private String idCard; // 身份证号

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserNum() {
        return userNum;
    }

    public void setUserNum(String userNum) {
        this.userNum = userNum;
    }
    public String getBaseCode() {
        return baseCode;
    }

    public void setBaseCode(String baseCode) {
        this.baseCode = baseCode;
    }
    public String getOldOrgName() {
        return oldOrgName;
    }

    public void setOldOrgName(String oldOrgName) {
        this.oldOrgName = oldOrgName;
    }
    public String getOldDeptName() {
        return oldDeptName;
    }

    public void setOldDeptName(String oldDeptName) {
        this.oldDeptName = oldDeptName;
    }
    public String getOldPostName() {
        return oldPostName;
    }

    public void setOldPostName(String oldPostName) {
        this.oldPostName = oldPostName;
    }
    public String getOldOrgCode() {
        return oldOrgCode;
    }

    public void setOldOrgCode(String oldOrgCode) {
        this.oldOrgCode = oldOrgCode;
    }
    public String getOldDeptCode() {
        return oldDeptCode;
    }

    public void setOldDeptCode(String oldDeptCode) {
        this.oldDeptCode = oldDeptCode;
    }
    public String getOldPostCode() {
        return oldPostCode;
    }

    public void setOldPostCode(String oldPostCode) {
        this.oldPostCode = oldPostCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getSexCode() {
        return sexCode;
    }

    public void setSexCode(String sexCode) {
        this.sexCode = sexCode;
    }
    public String getAge() {
        return age;
    }

    public void setAge(String age) {
        this.age = age;
    }
    public String getDegreesName() {
        return degreesName;
    }

    public void setDegreesName(String degreesName) {
        this.degreesName = degreesName;
    }
    public String getDegreesCode() {
        return degreesCode;
    }

    public void setDegreesCode(String degreesCode) {
        this.degreesCode = degreesCode;
    }
    public String getJobTitleName() {
        return jobTitleName;
    }

    public void setJobTitleName(String jobTitleName) {
        this.jobTitleName = jobTitleName;
    }
    public String getJobTitleCode() {
        return jobTitleCode;
    }

    public void setJobTitleCode(String jobTitleCode) {
        this.jobTitleCode = jobTitleCode;
    }
    public String getCertificateName() {
        return certificateName;
    }

    public void setCertificateName(String certificateName) {
        this.certificateName = certificateName;
    }
    public String getCertificateCode() {
        return certificateCode;
    }

    public void setCertificateCode(String certificateCode) {
        this.certificateCode = certificateCode;
    }
    public String getOldUserTypeName() {
        return oldUserTypeName;
    }

    public void setOldUserTypeName(String oldUserTypeName) {
        this.oldUserTypeName = oldUserTypeName;
    }
    public String getOldUserTypeCode() {
        return oldUserTypeCode;
    }

    public void setOldUserTypeCode(String oldUserTypeCode) {
        this.oldUserTypeCode = oldUserTypeCode;
    }
    public String getNewUserTypeName() {
        return newUserTypeName;
    }

    public void setNewUserTypeName(String newUserTypeName) {
        this.newUserTypeName = newUserTypeName;
    }
    public String getNewUserTypeCode() {
        return newUserTypeCode;
    }

    public void setNewUserTypeCode(String newUserTypeCode) {
        this.newUserTypeCode = newUserTypeCode;
    }
    public String getNewOrgName() {
        return newOrgName;
    }

    public void setNewOrgName(String newOrgName) {
        this.newOrgName = newOrgName;
    }
    public String getNewDeptName() {
        return newDeptName;
    }

    public void setNewDeptName(String newDeptName) {
        this.newDeptName = newDeptName;
    }
    public String getNewPostName() {
        return newPostName;
    }

    public void setNewPostName(String newPostName) {
        this.newPostName = newPostName;
    }
    public String getNewOrgCode() {
        return newOrgCode;
    }

    public void setNewOrgCode(String newOrgCode) {
        this.newOrgCode = newOrgCode;
    }
    public String getNewDeptCode() {
        return newDeptCode;
    }

    public void setNewDeptCode(String newDeptCode) {
        this.newDeptCode = newDeptCode;
    }
    public String getNewPostCode() {
        return newPostCode;
    }

    public void setNewPostCode(String newPostCode) {
        this.newPostCode = newPostCode;
    }
    public String getOldPostNumName() {
        return oldPostNumName;
    }

    public void setOldPostNumName(String oldPostNumName) {
        this.oldPostNumName = oldPostNumName;
    }
    public String getOldPostNumCode() {
        return oldPostNumCode;
    }

    public void setOldPostNumCode(String oldPostNumCode) {
        this.oldPostNumCode = oldPostNumCode;
    }
    public String getNewPostNumName() {
        return newPostNumName;
    }

    public void setNewPostNumName(String newPostNumName) {
        this.newPostNumName = newPostNumName;
    }
    public String getNewPostNumCode() {
        return newPostNumCode;
    }

    public void setNewPostNumCode(String newPostNumCode) {
        this.newPostNumCode = newPostNumCode;
    }
    public String getOldSocialOrgName() {
        return oldSocialOrgName;
    }

    public void setOldSocialOrgName(String oldSocialOrgName) {
        this.oldSocialOrgName = oldSocialOrgName;
    }
    public String getOldSocialOrgCode() {
        return oldSocialOrgCode;
    }

    public void setOldSocialOrgCode(String oldSocialOrgCode) {
        this.oldSocialOrgCode = oldSocialOrgCode;
    }
    public String getNewSocialOrgName() {
        return newSocialOrgName;
    }

    public void setNewSocialOrgName(String newSocialOrgName) {
        this.newSocialOrgName = newSocialOrgName;
    }
    public String getNewSocialOrgCode() {
        return newSocialOrgCode;
    }

    public void setNewSocialOrgCode(String newSocialOrgCode) {
        this.newSocialOrgCode = newSocialOrgCode;
    }
    public Date getChangeTime() {
        return changeTime;
    }

    public void setChangeTime(Date changeTime) {
        this.changeTime = changeTime;
    }
    public String getChangeTypeName() {
        return changeTypeName;
    }

    public void setChangeTypeName(String changeTypeName) {
        this.changeTypeName = changeTypeName;
    }
    public String getChangeTypeCode() {
        return changeTypeCode;
    }

    public void setChangeTypeCode(String changeTypeCode) {
        this.changeTypeCode = changeTypeCode;
    }
    public String getBpmRemark() {
        return bpmRemark;
    }

    public void setBpmRemark(String bpmRemark) {
        this.bpmRemark = bpmRemark;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }
    
}

==> ejc-hrm-api-3.0.0-20251211.012920-4-sources.jar: com/ejianc/business/hrm/vo/UserChangeVO.java <==
package com.ejianc.business.hrm.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 异动
 * 
 * @author generator
 * 
 */
public class UserChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private Long createUserId; // 创建人
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String userCode; // 用户编号
    private String userNum; // 用户序号
    private String baseCode; // 库编号
    private String oldOrgName; // 原单位名称
    private String oldDeptName; // 原部门名称
    private String oldPostName; // 原岗位名称
    private String oldOrgCode; // 原单位编号
    private String oldDeptCode; // 原部门编号
    private String oldPostCode; // 原岗位编号
    private String userName; // 姓名
    private String sexName; // 性别
    private String sexCode; // 性别编号
    private String age; // 年龄
    private String degreesName; // 学历
    private String degreesCode; // 学历编号
    private String jobTitleName; // 职称
    private String jobTitleCode; // 职称编号
    private String certificateName; // 执业资格
    private String certificateCode; // 执业资格编号
    private String oldUserTypeName; // 异动前人员类别
    private String oldUserTypeCode; // 异动前人员类别编号
    private String newUserTypeName; // 异动后人员类别
    private String newUserTypeCode; // 异动后人员类别编号
    private String newOrgName; // 调动后单位
    private String newDeptName; // 调动后部门
    private String newPostName; // 调动后岗位
    private String newOrgCode; // 调动后单位编号
    private String newDeptCode; // 调动后部门编号
    private String newPostCode; // 调动后岗位编号
    private String oldPostNumName; // 原所属岗位序列
    private String oldPostNumCode; // 原所属岗位序列
    private String newPostNumName; // 调动后所属岗位序列
    private String newPostNumCode; // 调动后所属岗位序列
    private String oldSocialOrgName; // 原社保参保单位
    private String oldSocialOrgCode; // 原社保参保单位编号
    private String newSocialOrgName; // 调动后参保单位
    private String newSocialOrgCode; // 调动后参保单位编号
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeTime; // 变动时间
    private String changeTypeName; // 异动类型
    private String changeTypeCode; // 异动类型编号
    private String bpmRemark; // 审批意见
    private String changeReason; // 异动原因
    private String billTypeName; // 业务单据名称
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date submitTime; // 业务提交时间
    private String idCard; // 身份证号


    private List<UserChangeJobDetailVO> userChangeJobDetailList = new ArrayList<>(); // 异动-兼职明细表

    public List<UserChangeJobDetailVO> getUserChangeJobDetailList() {
        return userChangeJobDetailList;
    }

    public void setUserChangeJobDetailList(List<UserChangeJobDetailVO> userChangeJobDetailList) {
        this.userChangeJobDetailList = userChangeJobDetailList;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserNum() {
        return userNum;
    }

    public void setUserNum(String userNum) {
        this.userNum = userNum;
    }
    public String getBaseCode() {
        return baseCode;
    }

    public void setBaseCode(String baseCode) {
        this.baseCode = baseCode;
    }
    public String getOldOrgName() {
        return oldOrgName;
    }

    public void setOldOrgName(String oldOrgName) {
        this.oldOrgName = oldOrgName;
    }
    public String getOldDeptName() {
        return oldDeptName;
    }

    public void setOldDeptName(String oldDeptName) {
        this.oldDeptName = oldDeptName;
    }
    public String getOldPostName() {
        return oldPostName;
    }

    public void setOldPostName(String oldPostName) {
        this.oldPostName = oldPostName;
    }
    public String getOldOrgCode() {
        return oldOrgCode;
    }

    public void setOldOrgCode(String oldOrgCode) {
        this.oldOrgCode = oldOrgCode;
    }
    public String getOldDeptCode() {
        return oldDeptCode;
    }

    public void setOldDeptCode(String oldDeptCode) {
        this.oldDeptCode = oldDeptCode;
    }
    public String getOldPostCode() {
        return oldPostCode;
    }

    public void setOldPostCode(String oldPostCode) {
        this.oldPostCode = oldPostCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getSexCode() {
        return sexCode;
    }

    public void setSexCode(String sexCode) {
        this.sexCode = sexCode;
    }
    public String getAge() {
        return age;
    }

    public void setAge(String age) {
        this.age = age;
    }
    public String getDegreesName() {
        return degreesName;
    }

    public void setDegreesName(String degreesName) {
        this.degreesName = degreesName;
    }
    public String getDegreesCode() {
        return degreesCode;
    }

    public void setDegreesCode(String degreesCode) {
        this.degreesCode = degreesCode;
    }
    public String getJobTitleName() {
        return jobTitleName;
    }

    public void setJobTitleName(String jobTitleName) {
        this.jobTitleName = jobTitleName;
    }
    public String getJobTitleCode() {
        return jobTitleCode;
    }

    public void setJobTitleCode(String jobTitleCode) {
        this.jobTitleCode = jobTitleCode;
    }
    public String getCertificateName() {
        return certificateName;
    }

    public void setCertificateName(String certificateName) {
        this.certificateName = certificateName;
    }
    public String getCertificateCode() {
        return certificateCode;
    }

    public void setCertificateCode(String certificateCode) {
        this.certificateCode = certificateCode;
    }
    public String getOldUserTypeName() {
        return oldUserTypeName;
    }

    public void setOldUserTypeName(String oldUserTypeName) {
        this.oldUserTypeName = oldUserTypeName;
    }
    public String getOldUserTypeCode() {
        return oldUserTypeCode;
    }

    public void setOldUserTypeCode(String oldUserTypeCode) {
        this.oldUserTypeCode = oldUserTypeCode;
    }
    public String getNewUserTypeName() {
        return newUserTypeName;
    }

    public void setNewUserTypeName(String newUserTypeName) {
        this.newUserTypeName = newUserTypeName;
    }
    public String getNewUserTypeCode() {
        return newUserTypeCode;
    }

    public void setNewUserTypeCode(String newUserTypeCode) {
        this.newUserTypeCode = newUserTypeCode;
    }
    public String getNewOrgName() {
        return newOrgName;
    }

    public void setNewOrgName(String newOrgName) {
        this.newOrgName = newOrgName;
    }
    public String getNewDeptName() {
        return newDeptName;
    }

    public void setNewDeptName(String newDeptName) {
        this.newDeptName = newDeptName;
    }
    public String getNewPostName() {
        return newPostName;
    }

    public void setNewPostName(String newPostName) {
        this.newPostName = newPostName;
    }
    public String getNewOrgCode() {
        return newOrgCode;
    }

    public void setNewOrgCode(String newOrgCode) {
        this.newOrgCode = newOrgCode;
    }
    public String getNewDeptCode() {
        return newDeptCode;
    }

    public void setNewDeptCode(String newDeptCode) {
        this.newDeptCode = newDeptCode;
    }
    public String getNewPostCode() {
        return newPostCode;
    }

    public void setNewPostCode(String newPostCode) {
        this.newPostCode = newPostCode;
    }
    public String getOldPostNumName() {
        return oldPostNumName;
    }

    public void setOldPostNumName(String oldPostNumName) {
        this.oldPostNumName = oldPostNumName;
    }
    public String getOldPostNumCode() {
        return oldPostNumCode;
    }

    public void setOldPostNumCode(String oldPostNumCode) {
        this.oldPostNumCode = oldPostNumCode;
    }
    public String getNewPostNumName() {
        return newPostNumName;
    }

    public void setNewPostNumName(String newPostNumName) {
        this.newPostNumName = newPostNumName;
    }
    public String getNewPostNumCode() {
        return newPostNumCode;
    }

    public void setNewPostNumCode(String newPostNumCode) {
        this.newPostNumCode = newPostNumCode;
    }
    public String getOldSocialOrgName() {
        return oldSocialOrgName;
    }

    public void setOldSocialOrgName(String oldSocialOrgName) {
        this.oldSocialOrgName = oldSocialOrgName;
    }
    public String getOldSocialOrgCode() {
        return oldSocialOrgCode;
    }

    public void setOldSocialOrgCode(String oldSocialOrgCode) {
        this.oldSocialOrgCode = oldSocialOrgCode;
    }
    public String getNewSocialOrgName() {
        return newSocialOrgName;
    }

    public void setNewSocialOrgName(String newSocialOrgName) {
        this.newSocialOrgName = newSocialOrgName;
    }
    public String getNewSocialOrgCode() {
        return newSocialOrgCode;
    }

    public void setNewSocialOrgCode(String newSocialOrgCode) {
        this.newSocialOrgCode = newSocialOrgCode;
    }
    public Date getChangeTime() {
        return changeTime;
    }

    public void setChangeTime(Date changeTime) {
        this.changeTime = changeTime;
    }
    public String getChangeTypeName() {
        return changeTypeName;
    }

    public void setChangeTypeName(String changeTypeName) {
        this.changeTypeName = changeTypeName;
    }
    public String getChangeTypeCode() {
        return changeTypeCode;
    }

    public void setChangeTypeCode(String changeTypeCode) {
        this.changeTypeCode = changeTypeCode;
    }
    public String getBpmRemark() {
        return bpmRemark;
    }

    public void setBpmRemark(String bpmRemark) {
        this.bpmRemark = bpmRemark;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }
    
}
